# Generated by Django 2.2.4 on 2019-08-27 04:49

from django.db import migrations
import djmoney.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('datatrans', '0005_optional_aliasregistration_transaction_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aliasregistration',
            name='amount',
            field=djmoney.models.fields.MoneyField(decimal_places=2, default_currency='CHF', max_digits=12),
        ),
        migrations.AlterField(
            model_name='payment',
            name='amount',
            field=djmoney.models.fields.MoneyField(decimal_places=2, default_currency='CHF', max_digits=12),
        ),
        migrations.AlterField(
            model_name='refund',
            name='amount',
            field=djmoney.models.fields.MoneyField(decimal_places=2, default_currency='CHF', max_digits=12),
        ),
    ]
