# Generated by Django 2.0 on 2018-01-29 07:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('datatrans', '0004_alias_registration_fields_optional'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aliasregistration',
            name='transaction_id',
            field=models.CharField(blank=True, max_length=18, null=True, unique=True),
        ),
    ]
