<html>

<head>
    <title>Datatrans - Example - {{ title }}</title>
</head>

<body>

<h2> {{ title }} </h2>

<form method="post">
    {% csrf_token %}
    {{ form.as_p }}
    <input type="submit" value="Submit"/>
</form>

</body>
</html>